Pylava_pylint
#############
Pylava_pylint is a community maintained fork of `Pylama_pylint
<https://github.com/klen/pylama_pylint>`_.

pylava_pylint -- Support Pylint_ in Pylava_.

.. image:: https://travis-ci.com/pyfocus/pylava_pylint.svg?branch=master
    :target: https://travis-ci.com/pyfocus/pylava_pylint
    :alt: Build Status

.. image:: https://coveralls.io/repos/github/pyfocus/pylava_pylint/badge.svg?branch=master
    :target: https://coveralls.io/github/pyfocus/pylava_pylint?branch=master
    :alt: Coveralls

.. image:: https://img.shields.io/pypi/v/pylava_pylint.svg
    :target: https://pypi.org/project/pylava_pylint/
    :alt: Version

.. contents::


Requirements
------------
- python >= 2.7


Installation
------------
Enter the following command to install Pylava_pylint. ::

    pip install pylava-pylint

With Python 3, you may need to enter the following command instead. ::

    pip3 install pylava-pylint


Usage
-----
Here are examples of a few commands that shows how Pylava_pylint may be
used with Pylava. ::

    pylava -l pylint
    pylava -l pylint,pycodestyle,pydocstyle


Support
-------
To report bugs, suggest improvements, or ask questions, please create a
new issue at http://github.com/pyfocus/pylava_pylint/issues.


Contributing
------------
Development of Pylava happens at the ``master`` branch of
https://github.com/pyfocus/pylava_pylint.


Contributors
------------
See AUTHORS_.

.. _AUTHORS: https://github.com/pyfocus/pylava_pylint/blob/master/AUTHORS.rst


License
-------
This is free software. You are permitted to use, copy, modify, merge,
publish, distribute, sublicense, and/or sell copies of it, under the
terms of the MIT License. See LICENSE.rst_ for the complete license.

This software is provided WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
LICENSE.rst_ for the complete disclaimer.

.. _LICENSE.rst: https://github.com/pyfocus/pylava/blob/master/LICENSE.rst

The original LICENSE file with the BSD-3-Clause license text is archived
in the `pylama-archive
<https://github.com/pyfocus/pylava_pylint/tree/master/pylama-archive>`_
directory.

.. _MIT license: https://github.com/pyfocus/pylava-pylint/blob/master/LICENSE.rst
.. _Pylint: https://www.pylint.org/
.. _Pylava: https://github.com/pyfocus/pylava
